// Sample solution to Frogger
// Author: Stein Norheim
// Algorithm: BFS

#include<iostream>
#include<vector>
#include<deque>
#include<cstring>

using namespace std;

class State {
public:
  int x;
  int y;
  int distance;
  
  State(int aX,int aY, int aDistance)
    : x(aX), y(aY), distance(aDistance) {};

  State() {
    x=0;
    y=0;
    distance=-1;
  }

  State forward() {return State(x,y+1,distance+1);}
  State backward() {return State(x,y-1,distance+1);}
  State left() {return State(x-1,y,distance+1);}
  State right() {return State(x+1,y,distance+1);}
  State still() {return State(x,y,distance+1);}
};

class Road : public vector<string> {
public:
  deque<State> q;
  bool visited[51][22][51];
  State laststates[51][22][51];
  int width;
  int height;
  int maxTurns;
  bool carPresent(int x, int y, int distance);

  bool tryState(const State& current,const State& s);
  int getMinTurns();
  
  bool stateVisited(const State& s) { return visited[s.x][s.y][s.distance % width];}
  void markVisited(const State& s) { visited[s.x][s.y][s.distance % width] = true;}

  const string& lane(int y) { return (*this)[height+1-y]; }
  int startX() { return lane(0).find("F"); }
  int finishX() { return lane(height+1).find("G"); };
  void printway(const State& goal);
  
};

bool
Road :: carPresent(int x,int y, int distance) {
  int offset;
  
  if (y % 2 == 1) {
    offset = width-(distance%width);
  } else {
    offset = distance%width;
  }
  return lane(y)[(x+offset)%width]=='X';
}



bool
Road :: tryState(const State& current,const State& s) {
  if ((s.x>=0) && (s.x<width) && (s.y>=0) && (s.y<=height+1) && (s.distance<=maxTurns) && !stateVisited(s) && !carPresent(s.x,s.y,s.distance)) {
    markVisited(s);
    q.push_back(s);
    laststates[s.x][s.y][s.distance % width]=State(current);
  }
}

void
Road :: printway(const State& goal) {
  const State* s = &goal;
  int y;
  int x;
  do {
    cout << s->x << " " << s->y << " " << s->distance << endl;
    for (y=height+1; y>=0; y--) {
      for (x=0; x<width; x++) {
        if (x==s->x && y==s->y)
          cout << "@";
        else
          cout << carPresent(x,y,s->distance);
      }
      cout << endl;
    }
    cout << endl;
    s = &(laststates[s->x][s->y][s->distance % width]);
  } while (s->distance>0);
}


int
Road :: getMinTurns() {
  memset(visited, 0, sizeof(visited));
  q.clear();

  int goalx = finishX();
  
  q.push_back(State(startX(),0,0));
  while (!q.empty()) {
    State s = q.front();
    q.pop_front();

    if ((s.x==goalx) && (s.y==height+1)) {
      printway(s);
      return s.distance;
    }
    
    if (s.x>0 && ((s.y%2==0) || !carPresent(s.x-1,s.y,s.distance)))
      tryState(s,s.left());
    if (s.x<width-1 && ((s.y%2==1) || !carPresent(s.x+1,s.y,s.distance)))
      tryState(s,s.right());
    tryState(s,s.forward());
    tryState(s,s.backward());
    tryState(s,s.still());
  }

  return -1;           
}

int main () {
  int nCases;
  int maxTurns;
  int nLanes;
  int minTurns;
  string s;
  Road road;
  
  cin >> nCases;
  for (int i=0; i<nCases; i++) {
    road.clear();
    cin >> road.maxTurns >> road.height >> road.width;
    for (int j=0; j<road.height+2; j++) {
      cin >> s;
      road.push_back(s);
    }
    minTurns = road.getMinTurns();
    if (minTurns>=0) {
      cout << "The minimum number of turns is " << minTurns << "." << endl;
    } else {
      cout << "The problem has no solution" << endl;
    }
  }
}
